# PyBA - Python Browser Automations

This is a browser automation software written in python. It can visit any website, automate testing, repetitive tasks, form filling and more.

## Framework

Documentation needs work.